@@ -8,8 +8,9 @@ class GenericRelationModel(models.Model):
         verbose_name = _('Content type'),
         related_name = 'content_type_set_for_%(class)s'
     )
-    object_pk = models.TextField(
+    object_pk = models.CharField(
         verbose_name = _('Object ID'),
+        max_length = 255,
     )
     content_object = generic.GenericForeignKey(
         ct_field   = 'content_type',
